Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1003)

Unified Diff: webrtc/sdk/objc/Framework/Headers/WebRTC/RTCRtpReceiver.h

Issue 1917193008: Adding getParameters/setParameters APIs to RtpReceiver. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: objc compile errors Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/sdk/objc/Framework/Headers/WebRTC/RTCPeerConnection.h ('k') | webrtc/sdk/sdk.gyp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/sdk/objc/Framework/Headers/WebRTC/RTCRtpReceiver.h
diff --git a/webrtc/sdk/objc/Framework/Headers/WebRTC/RTCRtpSender.h b/webrtc/sdk/objc/Framework/Headers/WebRTC/RTCRtpReceiver.h
similarity index 61%
copy from webrtc/sdk/objc/Framework/Headers/WebRTC/RTCRtpSender.h
copy to webrtc/sdk/objc/Framework/Headers/WebRTC/RTCRtpReceiver.h
index d910c6ceb280442bdec5864ee971a97a38b4628f..e98a8f3bea1d650b2677dae2d377ff780a997489 100644
--- a/webrtc/sdk/objc/Framework/Headers/WebRTC/RTCRtpSender.h
+++ b/webrtc/sdk/objc/Framework/Headers/WebRTC/RTCRtpReceiver.h
@@ -17,27 +17,31 @@
NS_ASSUME_NONNULL_BEGIN
RTC_EXPORT
-@protocol RTCRtpSender <NSObject>
+@protocol RTCRtpReceiver <NSObject>
-/** A unique identifier for this sender. */
-@property(nonatomic, readonly) NSString *senderId;
+/** A unique identifier for this receiver. */
+@property(nonatomic, readonly) NSString *receiverId;
/** The currently active RTCRtpParameters, as defined in
* https://www.w3.org/TR/webrtc/#idl-def-RTCRtpParameters.
+ *
+ * The WebRTC specification only defines RTCRtpParameters in terms of senders,
+ * but this API also applies them to receivers, similar to ORTC:
+ * http://ortc.org/wp-content/uploads/2016/03/ortc.html#rtcrtpparameters*.
*/
-@property(nonatomic, copy) RTCRtpParameters *parameters;
+@property(nonatomic, readonly) RTCRtpParameters *parameters;
-/** The RTCMediaStreamTrack associated with the sender.
+/** The RTCMediaStreamTrack associated with the receiver.
* Note: reading this property returns a new instance of
* RTCMediaStreamTrack. Use isEqual: instead of == to compare
* RTCMediaStreamTrack instances.
*/
-@property(nonatomic, copy, nullable) RTCMediaStreamTrack *track;
+@property(nonatomic, readonly) RTCMediaStreamTrack *track;
@end
RTC_EXPORT
-@interface RTCRtpSender : NSObject <RTCRtpSender>
+@interface RTCRtpReceiver : NSObject <RTCRtpReceiver>
- (instancetype)init NS_UNAVAILABLE;
« no previous file with comments | « webrtc/sdk/objc/Framework/Headers/WebRTC/RTCPeerConnection.h ('k') | webrtc/sdk/sdk.gyp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698